from icedata.datasets import birds
from icedata.datasets import coco
from icedata.datasets import fridge
from icedata.datasets import pennfudan
from icedata.datasets import pets
from icedata.datasets import voc
from icedata.datasets import biwi
from icedata.datasets import ochuman
