import icedata.utils
import icedata.template

from icedata.utils import *
from icedata.datasets import *


try:
    import importlib.metadata as importlib_metadata
except ModuleNotFoundError:
    import importlib_metadata

__version__ = importlib_metadata.version(__name__)
